@@ -1,6 +1,6 @@
 #' Create export table for a split-duration model
 #'
-#' \code{xtable}-like function for class ``\code{spdur}''.
+#' \code{xtable}-like function for class ``\code{spdur}''. 
 #' 
 #' @param x An object with class \code{spdur}.
 #' @param \dots Further arguments passed to \code{\link[xtable]{xtable}}.
@@ -11,11 +11,11 @@
 #' @return
 #' An object with class \code{xtable}.
 #' 
-#' @seealso \code{\link{xtable}}, or \code{\link{as.data.frame.spdur}} for a
+#' @seealso \code{\link[xtable]{xtable}}, or \code{\link{as.data.frame.spdur}} for a
 #'   simpler alternative that will convert a \code{spdur} object to a data frame
 #'   containing model parameter estimates.
 #' 
-#' For print formatting, see \code{\link{print.xtable}}.
+#' For print formatting, see \code{\link[xtable]{print.xtable}}.
 #' 
 #' @examples
 #' library(xtable)
@@ -23,11 +23,12 @@
 #' xtable(model.coups)
 #' print(xtable(model.coups), include.rownames=FALSE)
 #' 
-#' @importFrom xtable xtable
 #' @export
+#' @import xtable
 
 xtable.spdur <- function(x, ...) {
+
   model_table <- as.data.frame(x, row.names=FALSE)
-  res <- xtable(model_table, ...)
+  res <- xtable::xtable(model_table, ...)
   res
 }
\ No newline at end of file
